@@ -60,6 +60,7 @@ Plotter3D::Plotter3D(QAbstractItemModel* model)
     , m_scale(60)
     , m_currentAxisIndicator(InvalidAxis)
     , m_simpleRotation(false)
+    , m_referencePlaneColor(Qt::darkGray)
 {
     resetViewPrivate(QVector3D(-45, 0, -135));
 }
@@ -142,6 +143,10 @@ void Plotter3D::setViewport(const QRectF& vp)
     renderGL();
 }
 
+// add overloaded functions which call the underlying OpenGL function
+inline void glMultMatrix(const GLfloat  *m) { glMultMatrixf(m); }
+inline void glMultMatrix(const GLdouble *m) { glMultMatrixd(m); }
+
 void Plotter3D::drawPlots()
 {
     glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
@@ -152,7 +157,7 @@ void Plotter3D::drawPlots()
 
     glMatrixMode(GL_MODELVIEW);
     glLoadIdentity();
-    glMultMatrixd(m_rot.data());
+    glMultMatrix(m_rot.constData());
 
     // Object Drawing :
     glCallList(m_sceneObjects.value(Axes));
@@ -397,6 +402,14 @@ void Plotter3D::scale(GLdouble factor)
     renderGL();
 }
 
+inline QMatrix4x4 get_matrix(GLfloat *m)
+{
+    return QMatrix4x4(m[0],  m[1],  m[2],  m[3],
+                      m[4],  m[5],  m[6],  m[7],
+                      m[8],  m[9],  m[10], m[11],
+                      m[12], m[13], m[14], m[15]);
+}
+
 void Plotter3D::rotate(int dx, int dy)
 {
     GLdouble ax = -dy;
@@ -411,11 +424,11 @@ void Plotter3D::rotate(int dx, int dy)
         m_rot.rotate(angle, m_rotFixed.normalized());
         renderGL();
     } else {
-        GLdouble matrix[16] = {0}; // model view matrix from current OpenGL state
+        GLfloat matrix[16] = {0}; // model view matrix from current OpenGL state
 
-        glGetDoublev(GL_MODELVIEW_MATRIX, matrix);
+        glGetFloatv(GL_MODELVIEW_MATRIX, matrix);
 
-        QMatrix4x4 matrix4(matrix);
+        QMatrix4x4 matrix4(get_matrix(matrix));
         bool couldInvert;
         matrix4 = matrix4.inverted(&couldInvert);
 
@@ -737,6 +750,13 @@ void Plotter3D::initAxes()
     glEndList();
 }
 
+void Plotter3D::setReferencePlaneColor(const QColor& color)
+{
+    m_referencePlaneColor=color;
+    initRefPlanes();
+    renderGL();
+}
+
 void Plotter3D::initRefPlanes()
 {
     if (m_sceneObjects.contains(RefPlaneXY))
@@ -746,7 +766,7 @@ void Plotter3D::initRefPlanes()
 
     glNewList(m_sceneObjects.value(RefPlaneXY), GL_COMPILE );
     glLineWidth(1);
-    glColor3ub(48, 48, 48);
+    glColor3ub(m_referencePlaneColor.red(),m_referencePlaneColor.green(),m_referencePlaneColor.blue());
     glBegin( GL_LINES );
     glVertex3f(-150.0, 600.0, m_depth);
     glVertex3f(-150.0,-600.0, m_depth);
